summaryrefslogtreecommitdiffstats
path: root/Modules/FindVTK.cmake
diff options
context:
space:
mode:
authorKen Martin <ken.martin@kitware.com>2001-09-20 21:31:38 (GMT)
committerKen Martin <ken.martin@kitware.com>2001-09-20 21:31:38 (GMT)
commit7f5c61a570bbfe2dde673e61ad43ca1d2ed5d1e7 (patch)
treeda0f2d0ccc9422a3e6b50bd860e7ecf79cb0d54e /Modules/FindVTK.cmake
parent7d09ca52f15f9085d405aadcb253ec0392e35fde (diff)
downloadCMake-7f5c61a570bbfe2dde673e61ad43ca1d2ed5d1e7.zip
CMake-7f5c61a570bbfe2dde673e61ad43ca1d2ed5d1e7.tar.gz
CMake-7f5c61a570bbfe2dde673e61ad43ca1d2ed5d1e7.tar.bz2
updates
Diffstat (limited to 'Modules/FindVTK.cmake')
-rw-r--r--Modules/FindVTK.cmake42
1 files changed, 13 insertions, 29 deletions
diff --git a/Modules/FindVTK.cmake b/Modules/FindVTK.cmake
index 79715f4..4ce569c 100644
--- a/Modules/FindVTK.cmake
+++ b/Modules/FindVTK.cmake
@@ -3,37 +3,15 @@
#
# This module defines
#
# VTK_INSTALL_DIR - where is the installed version of VTK
# VTK_SOURCE_DIR - where is VTK source code
# VTK_BINARY_DIR - where is the binary tree (only defined if SOURCE_PATH is defined)
# USE_INSTALLED_VTK - sould an installed or source version of VTK be used
#
-
-#
-# Look for local source trees and builds of VTK
-#
-# look in the cmake list of recent source and bin dirs for this user
-#
-FIND_PATH(VTK_SOURCE_DIR Common/vtkObject.h
- [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource]
- [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource2]
- [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource3]
- [HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource4]
- ../VTK
- VTK
- $ENV{HOME}/VTK
- )
-
-#
-# If we found a source tree then set use_installed_vtk to 0
#
-IF (VTK_SOURCE_DIR)
- SET (USE_INSTALLED_VTK 0 CACHE BOOL "Is an installed (versus source) version of VTK used")
- #
- # Look for a binary tree
- #
- FIND_PATH(VTK_BINARY_DIR vtkConfigure.h
+# Look for a binary tree
+#
+FIND_PATH(VTK_BINARY_PATH vtkConfigure.h
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild]
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild2]
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild3]
@@ -45,7 +23,13 @@ IF (VTK_SOURCE_DIR)
$ENV{HOME}/VTKBIN
$ENV{HOME}/vtkbin
)
-ELSE (VTK_SOURCE_DIR)
+
+#
+# If we found a binary tree then set use_installed_vtk to 0
+#
+IF (VTK_BINARY_PATH)
+ SET (USE_INSTALLED_VTK 0 CACHE BOOL "Is an installed (versus source) version of VTK used")
+ELSE (VTK_BINARY_PATH)
# look for the vtk header files in installed places
FIND_PATH(VTK_INSTALL_PATH include/vtk/vtkObject.h
/usr/local
@@ -57,7 +41,7 @@ ELSE (VTK_SOURCE_DIR)
IF (VTK_INSTALL_PATH)
SET (USE_INSTALLED_VTK 1 CACHE BOOL "Is an installed (versus source) version of VTK used")
ENDIF (VTK_INSTALL_PATH)
-ENDIF (VTK_SOURCE_DIR)
+ENDIF (VTK_BINARY_PATH)
IF (USE_INSTALLED_VTK)
# look for the vtk header files in installed places
@@ -3,37 +3,15 @@
# This module defines
#
-# VTK_INSTALL_DIR - where is the installed version of VTK
-# VTK_SOURCE_DIR - where is VTK source code
-# VTK_BINARY_DIR - where is the binary tree (only defined if SOURCE_PATH is defined)
+# VTK_INSTALL_PATH - where is the installed version of VTK
+# VTK_BINARY_PATH - where is the binary tree (only defined if SOURCE_PATH is defined)
# USE_INSTALLED_VTK - sould an installed or source version of VTK be used
#